==> exo.ecm.wcm.portlet.newsletter-1.2-sources.jar: org/exoplatform/wcm/webui/newsletter/UINewsletterConstant.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.wcm.webui.newsletter;

/**
 * Created by The eXo Platform SAS
 * Author : eXoPlatform
 *          chuong.phan@exoplatform.com, phan.le.thanh.chuong@gmail.com
 * Jun 10, 2009  
 */
public class UINewsletterConstant {
  
  public static final String MANAGER_USERS_POPUP_WINDOW = "UIManagerUsersFormPopupWindow";
  
  public static final String CATEGORY_FORM_POPUP_WINDOW = "UICategoryFormPopupWindow";
  
  public static final String SUBSCRIPTION_FORM_POPUP_WINDOW = "UISubscriptionFormPopupWindow";
  
  public static final String ENTRY_FORM_POPUP_WINDOW = "UINewsletterEntryFormPopupWindow";
  
  public static final String USER_SELECTOR_POPUP_WINDOW    = "UIUserMemberSelectorPopupWindow";
  
  public static final String GROUP_SELECTOR_POPUP_WINDOW   = "UIGroupMemberSelectorPopupWindow";

  public static final String WEBCONTENT_SELECTOR_POPUP_WINDOW   = "UIWebcontentSelectorPopupWindow";
 
  public static final String WEBCONTENT_SELECTOR_FORM_POPUP_WINDOW = "UIWebcontentSelectorFormPopupWindow";
 
  public static final String ENTRY_CATEGORY_SELECTBOX = "UINewsletterEntryCategorySelectBox";

  public static final String ENTRY_SUBSCRIPTION_SELECTBOX = "UINewsletterEntrySubscriptionSelectBox";
  
  public static final String UIVIEW_ENTRY_PUPUP_WINDOW = "UINewsletterEntryViewForm";
  
}

==> exo.ecm.wcm.portlet.newsletter-1.2.7-sources.jar: org/exoplatform/wcm/webui/newsletter/UINewsletterConstant.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.wcm.webui.newsletter;

/**
 * Created by The eXo Platform SAS
 * Author : eXoPlatform
 * chuong.phan@exoplatform.com, phan.le.thanh.chuong@gmail.com
 * Jun 10, 2009
 */
public class UINewsletterConstant {
  
  /** The Constant MANAGER_USERS_POPUP_WINDOW. */
  public static final String MANAGER_USERS_POPUP_WINDOW = "UIManagerUsersFormPopupWindow";
  
  /** The Constant CATEGORY_FORM_POPUP_WINDOW. */
  public static final String CATEGORY_FORM_POPUP_WINDOW = "UICategoryFormPopupWindow";
  
  /** The Constant CATEGORY_FORM_POPUP_WINDOW. */
  public static final String REMOVE_MODERATORS_FORM_POPUP_WINDOW = "UIRemoveModeratorsFormPopupWindow";
  
  /** The Constant SUBSCRIPTION_FORM_POPUP_WINDOW. */
  public static final String SUBSCRIPTION_FORM_POPUP_WINDOW = "UISubscriptionFormPopupWindow";
  
  /** The Constant ENTRY_FORM_POPUP_WINDOW. */
  public static final String ENTRY_FORM_POPUP_WINDOW = "UINewsletterEntryFormPopupWindow";
  
  /** The Constant USER_SELECTOR_POPUP_WINDOW. */
  public static final String USER_SELECTOR_POPUP_WINDOW    = "UIUserMemberSelectorPopupWindow";
  
  /** The Constant GROUP_SELECTOR_POPUP_WINDOW. */
  public static final String GROUP_SELECTOR_POPUP_WINDOW   = "UIGroupMemberSelectorPopupWindow";

  /** The Constant WEBCONTENT_SELECTOR_POPUP_WINDOW. */
  public static final String WEBCONTENT_SELECTOR_POPUP_WINDOW   = "UIWebcontentSelectorPopupWindow";
 
  /** The Constant WEBCONTENT_SELECTOR_FORM_POPUP_WINDOW. */
  public static final String WEBCONTENT_SELECTOR_FORM_POPUP_WINDOW = "UIWebcontentSelectorFormPopupWindow";
 
  /** The Constant ENTRY_CATEGORY_SELECTBOX. */
  public static final String ENTRY_CATEGORY_SELECTBOX = "UINewsletterEntryCategorySelectBox";

  /** The Constant ENTRY_SUBSCRIPTION_SELECTBOX. */
  public static final String ENTRY_SUBSCRIPTION_SELECTBOX = "UINewsletterEntrySubscriptionSelectBox";
  
  /** The Constant UIVIEW_ENTRY_PUPUP_WINDOW. */
  public static final String UIVIEW_ENTRY_PUPUP_WINDOW = "UINewsletterEntryViewForm";
}
